@@ -38,7 +38,11 @@ from tensorflow import keras
 from scipy import interpolate
 
 class SimulatedModtranRT(TabularRT):
-    """A hybrid surrogate-model and emulator of MODTRAN-like results
+    """A hybrid surrogate-model and emulator of MODTRAN-like results.  A description of the model can be found in:
+
+     P.G. Brodrick, D.R. Thompson, J.E. Fahlen, M.L. Eastwood, C.M. Sarture, S.R. Lundeen, W. Olson-Duvall,
+     N. Carmon, and R.O. Green. Generalized radiative transfer emulation for imaging spectroscopy reflectance
+     retrievals. Remote Sensing of Environment, 261:112476, 2021.doi: 10.1016/j.rse.2021.112476.
 
     Args:
         engine_config: the configuration for this particular engine
